﻿using System.Text;
using System.Threading;
using System.IO.Ports;
using Microsoft.SPOT;
using SecretLabs.NETMF.Hardware.NetduinoPlus;

using Microtoolskit.Hardware.Displays;
using Microtoolskit.Hardware.Sensors;

namespace TempRS232
{
    public class Program
    {
        public static void Main()
        {   // LCD - Documentation de la classe SerialELCD162 http://webge.github.io/ELCD162/
            // Pour accéder au COM2, relier l'afficheur au connecteur O5 de la carte Tinkerkit
            // Création d'un objet afficheur série ELCD-162 (par défaut: COM2, 19200, None, 8, 1)
            ELCD162 lcd = new ELCD162();
            // --------------------------------------------------------------------------------
            // Convertisseur TTL <--> RS232 :  relié au connecteur Serial de la carte TINKERKIT   
            // Création d'un objet SerialPort pour la communication avec le PC
            //SerialPort UART = new SerialPort(SerialPorts.COM1, 56000, Parity.None, 8, StopBits.One);
            SerialPort UART = new SerialPort(SerialPorts.COM1, 9600, Parity.None, 8, StopBits.One);
            // --------------------------------------------------------------------------------
            // Capteur de température TMP102 : relié au connecteur TWI de la carte Tinkerkit
            // via un adaptateur 5V <--> 3,3V BSS138
            // Création d'un objet TMP102
            TMP102 CPTTEMP102 = new TMP102();
            

            // Initialisations
            CPTTEMP102.Init();
            lcd.Init(); lcd.ClearScreen(); lcd.CursorOff(); UART.Open();
            

            while (true)
            {
                // Mesure de la température
                var temperature = CPTTEMP102.ReadAsCelcius();
                // Création de la chaine de caractères à transmettre
                string temperatureOnLCD = "Temp. = " + temperature.ToString("f1") + "C";

                // Affichage sur le lcd
                lcd.PutString(temperatureOnLCD);

                // Conversion de la chaîne en octets
                string temperatureOnUART = "Temp. = " + temperature.ToString("f1") + "°C\r"; // \r = <CR>
                byte[] buffer = UTF8Encoding.UTF8.GetBytes(temperatureOnUART);

                // Envoie au port série
                UART.Write(buffer, 0, buffer.Length); // Si <CR> dans la chaîne, <LF> ajouté à la fin automatiquement !

                // Attente de 100ms entre deux envois
                Thread.Sleep(1000); lcd.ClearScreen();
            }
        }
    }
}
